@@ -1,5 +1,5 @@
 package HackaMol;
-$HackaMol::VERSION = '0.013';
+$HackaMol::VERSION = '0.014';
 #ABSTRACT: HackaMol: Object-Oriented Library for Molecular Hacking
 use 5.008;
 use Moose;
@@ -15,7 +15,8 @@ use Scalar::Util qw(refaddr);
 use Carp;
 
 with 'HackaMol::NameRole', 'HackaMol::MolReadRole', 
-     'HackaMol::PathRole','HackaMol::ExeRole';
+     'HackaMol::PathRole','HackaMol::ExeRole', 'HackaMol::FileFetchRole';
+
 
 sub read_file_append_mol{
     my $self = shift;
@@ -218,7 +219,7 @@ HackaMol - HackaMol: Object-Oriented Library for Molecular Hacking
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -424,11 +425,13 @@ L<VMD | http://www.ks.uiuc.edu/Research/vmd/>
 
 =item * L<HackaMol::ExeRole>
 
+=item * L<HackaMol::FileFetchRole>
+
 =item * L<HackaMol::MolReadRole>
 
 =item * L<HackaMol::NameRole>
 
-=item * L<HackaMol::NameRole|HackaMol::MolReadRole|HackaMol::PathRole|HackaMol::ExeRole>
+=item * L<HackaMol::NameRole|HackaMol::MolReadRole|HackaMol::PathRole|HackaMol::ExeRole|HackaMol::FileFetchRole>
 
 =item * L<HackaMol::PathRole>
 
